#ifndef DEFINES_H
# define DEFINES_H
# include <defines.h>
#endif
#include <environ.h>
#include <extra.h>
#include <xmalloc.h>

int check_env () {

 if (getenv(MCRYPT_KEY)!=NULL 
   || getenv(MCRYPT_ALGO)!=NULL
   || getenv(MCRYPT_MODE)!=NULL) return TRUE; /* ok */
 return FALSE;

}

char ** get_env_key() {
char **tmp;

 if (getenv(MCRYPT_KEY)!=NULL) {
  tmp= xmalloc(sizeof(char*));
  tmp[0]=getenv(MCRYPT_KEY);
  return tmp;
 }
 else {
  return NULL;
 }

}

char * get_env_algo() {

 return getenv(MCRYPT_ALGO);

}

char * get_env_mode() {

 return getenv(MCRYPT_MODE);

}

int get_env_bit_mode() {

 return atoi(getenv(MCRYPT_BIT_MODE));

}
